@@ -10,7 +10,6 @@ class GStream(object):
     为了和tornado的IOStream接口匹配
     """
 
-    _closed = None
     rfile = None
     wfile = None
     on_close_callback = None
@@ -19,15 +18,12 @@ class GStream(object):
         self.sock = sock
         self.rfile = sock.makefile('rb')
         self.wfile = sock.makefile('wb', 0)
-        self._closed = False
 
     def close(self, exc_info=False):
-        if self._closed:
+        if self.closed():
             # 如果已经关闭过，就直接返回了
             return
 
-        self._closed = True
-
         if self.rfile:
             safe_call(self.rfile.close)
             self.rfile = None
@@ -72,7 +68,7 @@ class GStream(object):
             safe_call(callback)
 
     def closed(self):
-        return self._closed
+        return not self.sock
 
     def writing(self):
         """
